==> ddCt_1.6.0.zip: ddCt/doc/rtPCR-usage.R <==
###################################################
### chunk number 1: setup
###################################################
#line 119 "rtPCR-usage.Rnw"
options(width=50)


###################################################
### chunk number 2: exec ddCt inside R eval=FALSE
###################################################
## #line 182 "rtPCR-usage.Rnw"
## scFile <- system.file("scripts/ddCt.R", package="ddCt")
## inputFile <- system.file("extdata/Experiment1.txt", package="ddCt")
## source(scFile)
## ddCtExec(list(inputFile=inputFile, ...))


###################################################
### chunk number 3: load ddct
###################################################
#line 195 "rtPCR-usage.Rnw"
source(system.file("scripts", "ddCt.R", package="ddCt"))


###################################################
### chunk number 4: specifyFiles
###################################################
#line 280 "rtPCR-usage.Rnw"
params <- list(loadPath = system.file("extdata", package="ddCt"),
               savePath = getwd())  


###################################################
### chunk number 5: The Data
###################################################
#line 316 "rtPCR-usage.Rnw"
params$confFile <- system.file("scripts", "ddCt.conf", package="ddCt")
params$inputFile <- c("Experiment1.txt")
params$sampleAnnotationFile = NULL
params$columnForGrouping    = NULL
params$onlyFromAnnotation   = FALSE


###################################################
### chunk number 6: transform
###################################################
#line 342 "rtPCR-usage.Rnw"
#params$geneAlias   = c("Gene1"="Gene A",
#                       "Gene4"="Gene B",
#			"Gene5"="Gene C",
#			"Gene2"="HK1",
#			"Gene3"="HK2")
#params$sampleAlias = NULL


###################################################
### chunk number 7: housekeeping
###################################################
#line 378 "rtPCR-usage.Rnw"
params$referenceGene <- c("Gene1", "Gene2")
params$referenceSample <- c("Sample1")


###################################################
### chunk number 8: threshold
###################################################
#line 395 "rtPCR-usage.Rnw"
params$threshold <- 40


###################################################
### chunk number 9: mode
###################################################
#line 402 "rtPCR-usage.Rnw"
params$mode = "median"


###################################################
### chunk number 10: effizienzen synta eval=FALSE
###################################################
## #line 415 "rtPCR-usage.Rnw"
## params$efficiencies       = c("Gene1"=1.9, "Gene2"=2, ...)


###################################################
### chunk number 11: effizienzen
###################################################
#line 426 "rtPCR-usage.Rnw"
#params$efficiencies       = c("Gene A"=1.9,"Gene B"=1.8,"HK1"=2,"Gene C"=2,"HK2"=2)
#params$efficienciesError  = c("Gene A"=0.01,"Gene B"=0.1,"HK1"=0.05,"Gene C"=0.01,"HK2"=0.2)


###################################################
### chunk number 12: PlotMode
###################################################
#line 444 "rtPCR-usage.Rnw"
params$plotMode = c("level","Ct")


###################################################
### chunk number 13: remaining
###################################################
#line 455 "rtPCR-usage.Rnw"
#REMAIN
params$genesRemainInOutput   = NULL
params$samplesRemainInOutput = NULL
#NOT
params$genesNotInOutput   = NULL
params$samplesNotInOutput = NULL


###################################################
### chunk number 14: grouping
###################################################
#line 467 "rtPCR-usage.Rnw"
params$groupingBySamples = FALSE


###################################################
### chunk number 15: plot0
###################################################
#line 474 "rtPCR-usage.Rnw"
params$plotPerObject = TRUE


###################################################
### chunk number 16: plot1
###################################################
#line 490 "rtPCR-usage.Rnw"
#params$groupingForPlot = NULL
#params$groupingColor   = c("#E41A1C","#377EB8","#4DAF4A","#984EA3","#FF7F00")


###################################################
### chunk number 17: plot2
###################################################
#line 498 "rtPCR-usage.Rnw"
#params$cutoff = NULL


###################################################
### chunk number 18: plot3
###################################################
#line 506 "rtPCR-usage.Rnw"
#params$brewerColor = c("Set3","Set1","Accent","Dark2","Spectral","PuOr","BrBG")


###################################################
### chunk number 19: plot4
###################################################
#line 514 "rtPCR-usage.Rnw"
params$legende  = TRUE


###################################################
### chunk number 20: ttest1
###################################################
#line 525 "rtPCR-usage.Rnw"
params$ttestPerform = FALSE


###################################################
### chunk number 21: ttest
###################################################
#line 535 "rtPCR-usage.Rnw"
#params$ttestCol = NULL


###################################################
### chunk number 22: ttest3
###################################################
#line 544 "rtPCR-usage.Rnw"
#params$pairsCol = NULL


###################################################
### chunk number 23: ttest4
###################################################
#line 550 "rtPCR-usage.Rnw"
#params$samplesRemainInTTest	 = NULL
#params$samplesNotInTTest	 = NULL


###################################################
### chunk number 24: correlation
###################################################
#line 565 "rtPCR-usage.Rnw"
#params$samplesRemainInCor = NULL
#params$samplesNotInCor    = NULL


###################################################
### chunk number 25: execute ddct
###################################################
#line 576 "rtPCR-usage.Rnw"
ddCtExec(params)


###################################################
### chunk number 26: Sweave eval=FALSE
###################################################
## #line 582 "rtPCR-usage.Rnw"
## Sweave("rtPCR-usage.Rnw")


###################################################
### chunk number 27: End of session
###################################################
#line 632 "rtPCR-usage.Rnw"
toLatex(sessionInfo())

==> ddCt_1.14.0.zip: ddCt/doc/rtPCR-usage.R <==
### R code from vignette source 'rtPCR-usage.Rnw'

###################################################
### code chunk number 1: setup
###################################################
options(width=50)


###################################################
### code chunk number 2: exec ddCt inside R (eval = FALSE)
###################################################
## scFile <- system.file("scripts/ddCt.R", package="ddCt")
## inputFile <- system.file("extdata/Experiment1.txt", package="ddCt")
## source(scFile)
## ddCtExec(list(inputFile=inputFile, ...))


###################################################
### code chunk number 3: load ddct
###################################################
source(system.file("scripts", "ddCt.R", package="ddCt"))


###################################################
### code chunk number 4: specifyFiles
###################################################
params <- list(loadPath = system.file("extdata", package="ddCt"),
               savePath = getwd())  


###################################################
### code chunk number 5: The Data
###################################################
params$confFile <- system.file("scripts", "ddCt.conf", package="ddCt")
params$inputFile <- c("Experiment1.txt")
params$sampleAnnotationFile = NULL
params$columnForGrouping    = NULL
params$onlyFromAnnotation   = FALSE


###################################################
### code chunk number 6: transform
###################################################
#params$geneAlias   = c("Gene1"="Gene A",
#                       "Gene4"="Gene B",
#			"Gene5"="Gene C",
#			"Gene2"="HK1",
#			"Gene3"="HK2")
#params$sampleAlias = NULL


###################################################
### code chunk number 7: housekeeping
###################################################
params$referenceGene <- c("Gene1", "Gene2")
params$referenceSample <- c("Sample1")


###################################################
### code chunk number 8: threshold
###################################################
params$threshold <- 40


###################################################
### code chunk number 9: mode
###################################################
params$mode = "median"


###################################################
### code chunk number 10: effizienzen synta (eval = FALSE)
###################################################
## params$efficiencies       = c("Gene1"=1.9, "Gene2"=2, ...)


###################################################
### code chunk number 11: effizienzen
###################################################
#params$efficiencies       = c("Gene A"=1.9,"Gene B"=1.8,"HK1"=2,"Gene C"=2,"HK2"=2)
#params$efficienciesError  = c("Gene A"=0.01,"Gene B"=0.1,"HK1"=0.05,"Gene C"=0.01,"HK2"=0.2)


###################################################
### code chunk number 12: PlotMode
###################################################
params$plotMode = c("level","Ct")


###################################################
### code chunk number 13: remaining
###################################################
#REMAIN
params$genesRemainInOutput   = NULL
params$samplesRemainInOutput = NULL
#NOT
params$genesNotInOutput   = NULL
params$samplesNotInOutput = NULL


###################################################
### code chunk number 14: grouping
###################################################
params$groupingBySamples = FALSE


###################################################
### code chunk number 15: plot0
###################################################
params$plotPerObject = TRUE


###################################################
### code chunk number 16: plot1
###################################################
#params$groupingForPlot = NULL
#params$groupingColor   = c("#E41A1C","#377EB8","#4DAF4A","#984EA3","#FF7F00")


###################################################
### code chunk number 17: plot2
###################################################
#params$cutoff = NULL


###################################################
### code chunk number 18: plot3
###################################################
#params$brewerColor = c("Set3","Set1","Accent","Dark2","Spectral","PuOr","BrBG")


###################################################
### code chunk number 19: plot4
###################################################
params$legende  = TRUE


###################################################
### code chunk number 20: ttest1
###################################################
params$ttestPerform = FALSE


###################################################
### code chunk number 21: ttest
###################################################
#params$ttestCol = NULL


###################################################
### code chunk number 22: ttest3
###################################################
#params$pairsCol = NULL


###################################################
### code chunk number 23: ttest4
###################################################
#params$samplesRemainInTTest	 = NULL
#params$samplesNotInTTest	 = NULL


###################################################
### code chunk number 24: correlation
###################################################
#params$samplesRemainInCor = NULL
#params$samplesNotInCor    = NULL


###################################################
### code chunk number 25: execute ddct
###################################################
ddCtExec(params)


###################################################
### code chunk number 26: Sweave (eval = FALSE)
###################################################
## Sweave("rtPCR-usage.Rnw")


###################################################
### code chunk number 27: End of session
###################################################
toLatex(sessionInfo())
